==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/plDevs_8h.js <==
var plDevs_8h =
[
    [ "PLD_bmpqt", "plDevs_8h.html#ad68cc9baaea52dc8947695df16a5cd45", null ],
    [ "PLD_epscairo", "plDevs_8h.html#a438a0783c60b30d0b8b5cac08d3e0bb2", null ],
    [ "PLD_epsqt", "plDevs_8h.html#ae1f7e10ccb83b15fd6dbbb54f91a751b", null ],
    [ "PLD_extcairo", "plDevs_8h.html#a0293d58f6385e6220eb731564391f718", null ],
    [ "PLD_extqt", "plDevs_8h.html#a60493b354dd7651bafe23208937aed6c", null ],
    [ "PLD_jpgqt", "plDevs_8h.html#a8346a6839e0f3eb400778f86bc6d0e6a", null ],
    [ "PLD_mem", "plDevs_8h.html#af7cc2be9d79431bd6a4f230f7b23bfa2", null ],
    [ "PLD_memcairo", "plDevs_8h.html#ae3a546675ee1b2f4a1ff58e273e15d25", null ],
    [ "PLD_memqt", "plDevs_8h.html#ac147823be7c830d9553c8a3ff265756a", null ],
    [ "PLD_ntk", "plDevs_8h.html#a81e54ac11e54e494ab01b329239ff1ba", null ],
    [ "PLD_null", "plDevs_8h.html#a71e58b4ded8ae6beab3bcabcb8d029e0", null ],
    [ "PLD_pdf", "plDevs_8h.html#a70505870e64fd56725497b8c3cdf8396", null ],
    [ "PLD_pdfcairo", "plDevs_8h.html#ac90d5368a9ccaabce48102854d5efc4f", null ],
    [ "PLD_pdfqt", "plDevs_8h.html#aba4a32298af75ebcfde5600e9e8cbb3a", null ],
    [ "PLD_pngcairo", "plDevs_8h.html#a487def092729b41d2990e353647c413d", null ],
    [ "PLD_pngqt", "plDevs_8h.html#a5eeb7c3e7207c2a446aa6dec78fdd878", null ],
    [ "PLD_ppmqt", "plDevs_8h.html#af687e8b8da0d8405796aaaaadac40189", null ],
    [ "PLD_ps", "plDevs_8h.html#a4696047dc34c94b449c94cfb57251b84", null ],
    [ "PLD_pscairo", "plDevs_8h.html#ae8c59bcfdfec6ecaae58e43eb3dbd5ae", null ],
    [ "PLD_psttf", "plDevs_8h.html#a47a3f3906dc4ce4382c8bb30b397d4db", null ],
    [ "PLD_qtwidget", "plDevs_8h.html#adf31ffa1b2c2aafd65217caf31f84b69", null ],
    [ "PLD_svg", "plDevs_8h.html#aff516eaaa04ea1d86619429cebab1f22", null ],
    [ "PLD_svgcairo", "plDevs_8h.html#a9398cd0089cd162a8607f22de8448871", null ],
    [ "PLD_svgqt", "plDevs_8h.html#a32c8b3e83ed70d3760a9e8d2a4f4305c", null ],
    [ "PLD_tiffqt", "plDevs_8h.html#afe8fd6ff145891b15b9eb8d6045519ef", null ],
    [ "PLD_tk", "plDevs_8h.html#a1e1fdf4cd01fc33ea9a2db279bef7d3f", null ],
    [ "PLD_tkwin", "plDevs_8h.html#ab19fba63e4f352c0bca5827dea2fe89d", null ],
    [ "PLD_wxwidgets", "plDevs_8h.html#a379f018c2bfed5c77e73ac42511d2ae2", null ],
    [ "PLD_xcairo", "plDevs_8h.html#a2ec08f682bd0dabeb204b4325e95f96a", null ],
    [ "PLD_xfig", "plDevs_8h.html#a38323998bda2fa7561b19f02aa97289a", null ],
    [ "PLD_xwin", "plDevs_8h.html#ad36dcafb053440ae52a61f9ba84efd63", null ]
];

==> plplot-5.15.0.tar.gz: plplot-5.15.0/doc/doxygen/html/plDevs_8h.js <==
var plDevs_8h =
[
    [ "PLD_bmpqt", "plDevs_8h.html#ad68cc9baaea52dc8947695df16a5cd45", null ],
    [ "PLD_epscairo", "plDevs_8h.html#a438a0783c60b30d0b8b5cac08d3e0bb2", null ],
    [ "PLD_extcairo", "plDevs_8h.html#a0293d58f6385e6220eb731564391f718", null ],
    [ "PLD_extqt", "plDevs_8h.html#a60493b354dd7651bafe23208937aed6c", null ],
    [ "PLD_jpgqt", "plDevs_8h.html#a8346a6839e0f3eb400778f86bc6d0e6a", null ],
    [ "PLD_mem", "plDevs_8h.html#af7cc2be9d79431bd6a4f230f7b23bfa2", null ],
    [ "PLD_memcairo", "plDevs_8h.html#ae3a546675ee1b2f4a1ff58e273e15d25", null ],
    [ "PLD_memqt", "plDevs_8h.html#ac147823be7c830d9553c8a3ff265756a", null ],
    [ "PLD_ntk", "plDevs_8h.html#a81e54ac11e54e494ab01b329239ff1ba", null ],
    [ "PLD_null", "plDevs_8h.html#a71e58b4ded8ae6beab3bcabcb8d029e0", null ],
    [ "PLD_pdf", "plDevs_8h.html#a70505870e64fd56725497b8c3cdf8396", null ],
    [ "PLD_pdfcairo", "plDevs_8h.html#ac90d5368a9ccaabce48102854d5efc4f", null ],
    [ "PLD_pdfqt", "plDevs_8h.html#aba4a32298af75ebcfde5600e9e8cbb3a", null ],
    [ "PLD_pngcairo", "plDevs_8h.html#a487def092729b41d2990e353647c413d", null ],
    [ "PLD_pngqt", "plDevs_8h.html#a5eeb7c3e7207c2a446aa6dec78fdd878", null ],
    [ "PLD_ppmqt", "plDevs_8h.html#af687e8b8da0d8405796aaaaadac40189", null ],
    [ "PLD_ps", "plDevs_8h.html#a4696047dc34c94b449c94cfb57251b84", null ],
    [ "PLD_psc", "plDevs_8h.html#a84cab3750b1385e172346425eb3ab185", null ],
    [ "PLD_pscairo", "plDevs_8h.html#ae8c59bcfdfec6ecaae58e43eb3dbd5ae", null ],
    [ "PLD_psttf", "plDevs_8h.html#a47a3f3906dc4ce4382c8bb30b397d4db", null ],
    [ "PLD_psttfc", "plDevs_8h.html#ab8bcf52744e47f14a936c995e378473f", null ],
    [ "PLD_qtwidget", "plDevs_8h.html#adf31ffa1b2c2aafd65217caf31f84b69", null ],
    [ "PLD_svg", "plDevs_8h.html#aff516eaaa04ea1d86619429cebab1f22", null ],
    [ "PLD_svgcairo", "plDevs_8h.html#a9398cd0089cd162a8607f22de8448871", null ],
    [ "PLD_svgqt", "plDevs_8h.html#a32c8b3e83ed70d3760a9e8d2a4f4305c", null ],
    [ "PLD_tiffqt", "plDevs_8h.html#afe8fd6ff145891b15b9eb8d6045519ef", null ],
    [ "PLD_tk", "plDevs_8h.html#a1e1fdf4cd01fc33ea9a2db279bef7d3f", null ],
    [ "PLD_tkwin", "plDevs_8h.html#ab19fba63e4f352c0bca5827dea2fe89d", null ],
    [ "PLD_wxwidgets", "plDevs_8h.html#a379f018c2bfed5c77e73ac42511d2ae2", null ],
    [ "PLD_xcairo", "plDevs_8h.html#a2ec08f682bd0dabeb204b4325e95f96a", null ],
    [ "PLD_xfig", "plDevs_8h.html#a38323998bda2fa7561b19f02aa97289a", null ],
    [ "PLD_xwin", "plDevs_8h.html#ad36dcafb053440ae52a61f9ba84efd63", null ]
];
